@@ -22,14 +22,13 @@
 #  gpodder.gtkui.config -- Config object with GTK+ support (2009-08-24)
 #
 
-
-from gi.repository import Gtk
-from gi.repository import Gdk
-from gi.repository import Pango
+import gi  # isort:skip
+gi.require_version('Gdk', '3.0')  # isort:skip
+gi.require_version('Gtk', '3.0')  # isort:skip
+from gi.repository import Gdk, Gtk, Pango
 
 import gpodder
-from gpodder import util
-from gpodder import config
+from gpodder import config, util
 
 _ = gpodder.gettext
 
@@ -157,7 +156,11 @@ class UIConfig(config.Config):
         if gpodder.ui.win32:
             window.set_gravity(Gdk.Gravity.STATIC)
 
-        window.resize(cfg.width, cfg.height)
+        if cfg.width != -1 and cfg.height != -1:
+            window.resize(cfg.width, cfg.height)
+
+        # Not all platforms can natively restore position, gPodder must handle it.
+        # https://github.com/gpodder/gpodder/pull/933#issuecomment-818039693
         if cfg.x == -1 or cfg.y == -1:
             window.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)
         else:
@@ -166,9 +169,11 @@ class UIConfig(config.Config):
         # Ignore events while we're connecting to the window
         self.__ignore_window_events = True
 
+        # Get window state, correct size comes from window.get_size(),
+        # see https://developer.gnome.org/SaveWindowState/
         def _receive_configure_event(widget, event):
-            x_pos, y_pos = event.x, event.y
-            width_size, height_size = event.width, event.height
+            x_pos, y_pos = widget.get_position()
+            width_size, height_size = widget.get_size()
             maximized = bool(event.window.get_state() & Gdk.WindowState.MAXIMIZED)
             if not self.__ignore_window_events and not maximized:
                 cfg.x = x_pos
